summaryrefslogtreecommitdiffstats
path: root/kspread/kspread_format.cc
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kspread/kspread_format.cc
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kspread/kspread_format.cc')
-rw-r--r--kspread/kspread_format.cc52
1 files changed, 26 insertions, 26 deletions
diff --git a/kspread/kspread_format.cc b/kspread/kspread_format.cc
index 73c0bbff..587bf500 100644
--- a/kspread/kspread_format.cc
+++ b/kspread/kspread_format.cc
@@ -64,7 +64,7 @@ double Format::s_rowHeight = 20.0;
Format::Format( Sheet * _sheet, Style * _style )
: m_pSheet( _sheet ),
m_pStyle( _style ),
- m_tqmask( 0 ),
+ m_mask( 0 ),
m_bNoFallBack( 0 ),
m_flagsMask( 0 ),
m_strComment( 0 ),
@@ -116,7 +116,7 @@ void Format::copy( const Format & _l )
setStyle( _l.m_pStyle );
- m_tqmask = _l.m_tqmask;
+ m_mask = _l.m_mask;
m_flagsMask = _l.m_flagsMask;
m_bNoFallBack = _l.m_bNoFallBack;
@@ -162,14 +162,14 @@ bool Format::testFlag( FormatFlags flag ) const
void Format::clearProperties()
{
- m_tqmask = 0;
+ m_mask = 0;
m_pStyle->clearFeature( (Style::FlagsSet) ~(uint)0 );
formatChanged();
}
void Format::clearProperty( Properties p )
{
- m_tqmask &= ~(uint)p;
+ m_mask &= ~(uint)p;
m_pStyle->clearFeature( (Style::FlagsSet) p );
formatChanged();
}
@@ -181,12 +181,12 @@ bool Format::hasProperty( Properties p, bool withoutParent ) const
if ( m_pStyle->hasFeature( (Style::FlagsSet) p, withoutParent ) )
return true;
- return ( m_tqmask & (uint)p );
+ return ( m_mask & (uint)p );
}
void Format::setProperty( Properties p )
{
- m_tqmask |= (uint)p;
+ m_mask |= (uint)p;
}
void Format::clearNoFallBackProperties()
@@ -248,8 +248,8 @@ TQDomElement Format::saveFormat( TQDomDocument & doc, int _col, int _row, bool f
}
else
{
- if ( m_pStyle->tqparent() && m_pStyle->tqparent()->name().length() > 0 )
- format.setAttribute( "tqparent", m_pStyle->tqparent()->name() );
+ if ( m_pStyle->parent() && m_pStyle->parent()->name().length() > 0 )
+ format.setAttribute( "parent", m_pStyle->parent()->name() );
}
if ( hasProperty( PAlign, true ) || hasNoFallBackProperties( PAlign ) || force )
@@ -369,8 +369,8 @@ TQDomElement Format::saveFormat( TQDomDocument& doc, bool force, bool copy ) con
}
else
{
- if ( m_pStyle->tqparent() && m_pStyle->parentName().length() > 0 )
- format.setAttribute( "tqparent", m_pStyle->parentName() );
+ if ( m_pStyle->parent() && m_pStyle->parentName().length() > 0 )
+ format.setAttribute( "parent", m_pStyle->parentName() );
}
if ( hasProperty( PAlign, true ) || hasNoFallBackProperties( PAlign ) || force )
@@ -499,10 +499,10 @@ bool Format::loadFormat( const TQDomElement & f, Paste::Mode pm, bool paste )
return false;
}
else
- if ( f.hasAttribute( "tqparent" ) )
+ if ( f.hasAttribute( "parent" ) )
{
- CustomStyle* s = static_cast<CustomStyle*>( m_pSheet->doc()->styleManager()->style( f.attribute( "tqparent" ) ) );
- //kdDebug() << "Loading Style, tqparent: " << s->name() << ": " << s << endl;
+ CustomStyle* s = static_cast<CustomStyle*>( m_pSheet->doc()->styleManager()->style( f.attribute( "parent" ) ) );
+ //kdDebug() << "Loading Style, parent: " << s->name() << ": " << s << endl;
if ( s )
{
@@ -835,10 +835,10 @@ bool Format::loadOasisStyleProperties( KoStyleStack & styleStack, const KoOasisS
return false;
}
else
- if ( f.hasAttribute( "tqparent" ) )
+ if ( f.hasAttribute( "parent" ) )
{
- CustomStyle * s = (CustomStyle *) m_pSheet->doc()->styleManager()->style( f.attribute( "tqparent" ) );
- //kdDebug() << "Loading Style, tqparent: " << s->name() << ": " << s << endl;
+ CustomStyle * s = (CustomStyle *) m_pSheet->doc()->styleManager()->style( f.attribute( "parent" ) );
+ //kdDebug() << "Loading Style, parent: " << s->name() << ": " << s << endl;
if ( s )
{
@@ -850,9 +850,9 @@ bool Format::loadOasisStyleProperties( KoStyleStack & styleStack, const KoOasisS
}
}
#endif
- if ( styleStack.hasAttributeNS( KoXmlNS::style, "tqparent-style-name" ) )
+ if ( styleStack.hasAttributeNS( KoXmlNS::style, "parent-style-name" ) )
{
- Style * s = m_pSheet->doc()->styleManager()->style( styleStack.attributeNS( KoXmlNS::style, "tqparent-style-name" ) );
+ Style * s = m_pSheet->doc()->styleManager()->style( styleStack.attributeNS( KoXmlNS::style, "parent-style-name" ) );
//kdDebug() << "Using style: " << f.attribute( "style-name" ) << ", s: " << s << endl;
if ( s )
@@ -1465,12 +1465,12 @@ void Format::setBackGroundBrushColor( const TQColor & c )
void Format::setTextFont( const TQFont & _f )
{
- if( m_pStyle->tqparent() && _f == m_pStyle->tqparent()->font())
+ if( m_pStyle->parent() && _f == m_pStyle->parent()->font())
{
clearProperty( PFont );
setNoFallBackProperties( PFont );
}
- else if( !m_pStyle->tqparent() && _f == KoGlobal::defaultFont() )
+ else if( !m_pStyle->parent() && _f == KoGlobal::defaultFont() )
{
clearProperty( PFont );
setNoFallBackProperties( PFont );
@@ -2480,11 +2480,11 @@ const Format* Format::fallbackFormat( int, int row ) const
bool Format::isDefault() const
{
// NOTE Stefan: Don't compare sheet and cell.
- // Because of the comment we have to check m_tqmask.
- if ( ( m_tqmask & PComment ) && m_strComment != 0 )
+ // Because of the comment we have to check m_mask.
+ if ( ( m_mask & PComment ) && m_strComment != 0 )
return false;
#if 0 // These are copied in Style.
- if ( m_tqmask ) // Properties
+ if ( m_mask ) // Properties
return false;
if ( m_flagsMask != 0 ) // FormatFlags
return false;
@@ -2497,11 +2497,11 @@ bool Format::isDefault() const
bool Format::operator==( const Format& other ) const
{
// NOTE Stefan: Don't compare sheet and cell.
- // Because of the comment we have to check m_tqmask.
- if ( ( m_tqmask & other.m_tqmask & PComment ) && m_strComment != other.m_strComment )
+ // Because of the comment we have to check m_mask.
+ if ( ( m_mask & other.m_mask & PComment ) && m_strComment != other.m_strComment )
return false;
#if 0 // These are copied in Style.
- if ( m_tqmask != other.m_tqmask ) // Properties
+ if ( m_mask != other.m_mask ) // Properties
return false;
if ( m_flagsMask != other.m_flagsMask ) // FormatFlags
return false;